{{ '#' * (len(modname)+1) }}
{{ modname }}
{{ '#' * (len(modname)+1) }}

.. start short_desc
.. end short_desc

.. start shields
.. end shields

Installation
---------------

.. start installation
.. end installation

.. toctree::
	:hidden:

	Home<self>

.. toctree::
	:maxdepth: 3
	:caption: API Reference
	:glob:

	api/*

.. toctree::
	:maxdepth: 3
	:caption: Contributing

	contributing
	Source

.. start links
.. end links
